<?php

namespace Drupal\ro_dashboard\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Config form for the Multi Site Status Dashboard.
 *
 * @package Drupal\ro_dashboard\Form
 */
class RoDashboardSettingsForm extends ConfigFormBase {

  /**
   * {@inheritDoc}
   */
  protected function getEditableConfigNames() {
    return [
      'ro_dashboard.settings',
    ];
  }

  /**
   * {@inheritDoc}
   */
  public function getFormId() {
    return 'ro_dashboard_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('ro_dashboard.settings');
    $form['site_guardian'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Site Guardian global settings'),
    ];
    $form['site_guardian']['sg_description'] = [
      '#markup' => $this->t('<a href="@sg_url">Site Guardian</a> is a
      Module that helps you collect status information about your site.
      It will also show if there are updates available for your site.
      The settings below are <strong>global</strong> settings that apply to all
      sites. You can add site-specific settings when you add or edit a site.', [
        '@sg_url' => 'https://www.drupal.org/project/site_guardian',
      ]),
    ];
    $form['site_guardian']['sg_status_report_ignore'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Ignored these items'),
      '#description' => $this->t('Add status report items that can be
      ignored. When these values produce an error or warning, this will not
      affect the status of the site.<br><strong>One item per line.</strong>'),
      '#default_value' => $config->get('sg_status_report_ignore'),
    ];
    $form['site_guardian']['sg_module_update_report_ignore'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Ignore updates for these modules'),
      '#description' => $this->t('Add modules for which updates can be
      ignored. When these modules have an update, this will not
      effect the status of the site.<br><strong>One module per line.</strong>'),
      '#default_value' => $config->get('sg_module_update_report_ignore'),
    ];

    $form['ssl_check'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('SSL certificate expiry check'),
    ];
    $form['ssl_check']['ssl_check_description'] = [
      '#markup' => $this->t('This module can check if the certificate
      for a domain name is expired. This check can be enabled per site.'),
    ];
    $form['ssl_check']['ssl_expiry_check_days'] = [
      '#type' => 'number',
      '#title' => $this->t('SSL certificate expiry check days'),
      '#description' => $this->t('Set how many days before the
      SSL certificate expiry date the module will start checking if the certificate
      has been renewed.<br/>This check will only be performed if it is enabled
      for the site.<br/><strong>Default: 14 days</strong>'),
      '#default_value' => $config->get('ssl_expiry_check_days') ?? 14,
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    // @todo Add validation.
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('ro_dashboard.settings')
      ->set('sg_status_report_ignore', $form_state->getValue('sg_status_report_ignore'))
      ->set('sg_module_update_report_ignore', $form_state->getValue('sg_module_update_report_ignore'))
      ->set('ssl_expiry_check_days', (int) $form_state->getValue('ssl_expiry_check_days'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
